package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.CommissionConfigClient;
import com.chelvc.cloud.vehicle.client.dto.CommissionConfigDTO;
import com.chelvc.cloud.vehicle.client.param.CommissionConfigModifyParam;
import com.chelvc.cloud.vehicle.client.param.CommissionConfigPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 抽成比列接口接口
 *
 * @author liude
 * @Date 2023/12/29
 **/
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CommissionConfigController {
    private final CommissionConfigClient commissionConfigClient;

    /**
     * 新增抽成比列
     *
     * @param param 新增参数
     * @return 抽成比列主键
     */
    @PostMapping("/commissionConfig")
    public Long addCommissionConfig(@RequestBody @Valid CommissionConfigModifyParam param) {
        return this.commissionConfigClient.addCommissionConfig(param);
    }

    /**
     * 修改抽成比列
     *
     * @param id    抽成比列主键
     * @param param 修改参数
     */
    @PutMapping("/commissionConfig/{id}")
    public void updateCommissionConfig(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id,
                                       @RequestBody @Valid CommissionConfigModifyParam param) {
        this.commissionConfigClient.updateCommissionConfig(id, param);
    }

    /**
     * 删除抽成比列
     *
     * @param id 抽成比列主键
     */
    @PutMapping("/commissionConfig/delete/{id}")
    public void deleteCommissionConfig(@PathVariable("id") @Min(value = 1, message = "轮播图主键不能小于1") Long id) {
        this.commissionConfigClient.deleteCommissionConfig(id);
    }

    /**
     * 查询抽成比列分页
     *
     * @param param 查询参数
     * @return 抽成比列分页信息
     */
    @GetMapping("/CommissionConfig/paging")
    public Pagination<CommissionConfigDTO> getCommissionConfigPaging(@Valid CommissionConfigPagingParam param) {
        return this.commissionConfigClient.getCommissionConfigPaging(param);
    }
}
