package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.CouponClient;
import com.chelvc.cloud.vehicle.client.dto.CouponDTO;
import com.chelvc.cloud.vehicle.client.param.CouponModifyParam;
import com.chelvc.cloud.vehicle.client.param.CouponPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品优惠券接口
 *
 * @author liude
 * @Date 2023/8/29
 **/
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CouponController {
    private final CouponClient couponClient;

    /**
     * 新增商品优惠券
     *
     * @param param 新增参数
     * @return 商品优惠券主键
     */
    @PostMapping("/coupon")
    public Long addCoupon(@RequestBody @Valid CouponModifyParam param) {
        return this.couponClient.addCoupon(param);
    }

    /**
     * 修改商品优惠券
     *
     * @param id    商品优惠券主键
     * @param param 修改参数
     */
    @PutMapping("/coupon/{id}")
    public void updateCoupon(@PathVariable("id") @Min(value = 1, message = "商品优惠券主键不能小于1") Long id,
                             @RequestBody @Valid CouponModifyParam param) {
        this.couponClient.updateCoupon(id, param);
    }

    /**
     * 删除商品优惠券
     *
     * @param id 商品优惠券主键
     */
    @PutMapping("/coupon/delete/{id}")
    public void deleteCoupon(@PathVariable("id") @Min(value = 1, message = "商品优惠券主键不能小于1") Long id) {
        this.couponClient.deleteCoupon(id);
    }

    /**
     * 查询商品优惠券分页
     *
     * @param param 查询参数
     * @return 商品优惠券分页信息
     */
    @GetMapping("/coupon/paging")
    public Pagination<CouponDTO> getCouponPaging(@Valid CouponPagingParam param) {
        return this.couponClient.getCouponPaging(param);
    }
}
