package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.client.DynamicCommentClient;
import com.chelvc.cloud.vehicle.client.dto.DynamicCommentDTO;
import com.chelvc.cloud.vehicle.client.param.ExamineDynamicParam;
import com.chelvc.cloud.vehicle.client.param.QueryAdminDynamicParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 评论信息
 *
 * @author: igl
 * @date: 2023/8/17 22:18
 */
@Authorize
@Validated
@RestController
@RequestMapping("/comment")
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class DynamicCommentController {
    private final DynamicCommentClient dynamicCommentClient;

    /**
     * 查询列表
     *
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @GetMapping("/list")
    public Pagination<DynamicCommentDTO> list(QueryAdminDynamicParam param) {
        return this.dynamicCommentClient.queryAdminPageList(param);
    }

    /**
     * 动态手动审核
     *
     * @param param
     * @author igl
     * @date 2023/8/17 17:25
     */
    @PutMapping("/examine")
    public void examine(@Validated @RequestBody ExamineDynamicParam param) {
        this.dynamicCommentClient.examine(param.getId(), param.getExamine());
    }
}
