package com.chelvc.cloud.admin.controller;

import java.util.List;
import java.util.Map;
import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.GoodsClient;
import com.chelvc.cloud.vehicle.client.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.client.param.GoodsModifyParam;
import com.chelvc.cloud.vehicle.client.param.GoodsPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品接口
 *
 * @author liude
 * @Date 2023/8/29
 **/
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class GoodsController {
    private final GoodsClient goodsClient;

    /**
     * 新增商品
     *
     * @param param 新增参数
     * @return 商品主键
     */
    @PostMapping("/goods")
    public Long addGoods(@RequestBody @Valid GoodsModifyParam param) {
        return this.goodsClient.addGoods(param);
    }

    /**
     * 修改商品
     *
     * @param id    商品主键
     * @param param 修改参数
     */
    @PutMapping("/goods/{id}")
    public void updateGoods(@PathVariable("id") @Min(value = 1, message = "商品主键不能小于1") Long id,
                            @RequestBody @Valid GoodsModifyParam param) {
        this.goodsClient.updateGoods(id, param);
    }

    /**
     * 删除商品
     *
     * @param id 商品主键
     */
    @PutMapping("/goods/delete/{id}")
    public void deleteGoods(@PathVariable("id") @Min(value = 1, message = "商品主键不能小于1") Long id) {
        this.goodsClient.deleteGoods(id);
    }

    /**
     * 查询商品分页
     *
     * @param param 查询参数
     * @return 商品分页信息
     */
    @GetMapping("/goods/paging")
    public Pagination<GoodsDTO> getGoodsPaging(@Valid GoodsPagingParam param) {
        return this.goodsClient.getGoodsPaging(param);
    }

    /**
     * 查询商品得成交量以及成交金额
     */
    @GetMapping("/goods/orderAmount")
    public List<Map<String, Object>> orderAmount() {
        return this.goodsClient.getGoodsAmount();
    }
}
