package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;

import com.chelvc.cloud.user.client.model.Scope;
import com.chelvc.cloud.vehicle.client.UserInviteClient;
import com.chelvc.cloud.vehicle.client.dto.TeamDTO;
import com.chelvc.cloud.vehicle.client.param.TeamInvitePageParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户分销接口
 *
 * @author liude
 * @date 2024/4/30
 */
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class InviteUserController {
    private final UserInviteClient userInviteClient;

    /**
     * 查询用户分销分页
     *
     * @param param 查询参数
     * @return 用户分销分页信息
     */
    @GetMapping("/userInvite/paging")
    public TeamDTO getUserInvitePaging(@Valid TeamInvitePageParam param) {
        Long userId = SessionContextHolder.getId();
        Scope scope = StringUtils.ifEmpty(SessionContextHolder.getScope(), Scope::parse);
        if (scope == Scope.ADMIN) {
            return this.userInviteClient.inviteList(param);
        } else {
            return this.userInviteClient.teamList(param, userId);
        }
    }
}
