package com.chelvc.cloud.admin.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.user.client.MenuClient;
import com.chelvc.cloud.user.client.dto.MenuDTO;
import com.chelvc.cloud.user.client.param.MenuModifyParam;
import com.chelvc.cloud.user.client.param.MenuQueryParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 菜单接口
 *
 * @author Woody
 * @date 2021/10/20
 */
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MenuController {
    private final MenuClient menuClient;

    /**
     * 新增菜单
     *
     * @param param 新增参数
     * @return 菜单主键
     */
    @PostMapping("/menu")
    public Integer addMenu(@RequestBody @Valid MenuModifyParam param) {
        return this.menuClient.addMenu(param);
    }

    /**
     * 修改菜单
     *
     * @param id    菜单主键
     * @param param 修改参数
     */
    @PutMapping("/menu/{id}")
    public void updateMenu(@PathVariable("id") @Min(value = 1, message = "菜单主键不能小于1") Integer id,
                           @RequestBody @Valid MenuModifyParam param) {
        this.menuClient.updateMenu(id, param);
    }

    /**
     * 获取菜单信息
     *
     * @param id 菜单主键
     * @return 菜单信息
     */
    @GetMapping("/menu/{id}")
    public MenuDTO getMenu(@PathVariable("id") @Min(value = 1, message = "菜单主键不能小于1") Integer id) {
        return this.menuClient.getMenu(id);
    }

    /**
     * 查询菜单树列表
     *
     * @param param 查询参数
     * @return 菜单树列表
     */
    @GetMapping("/menu/trees")
    public List<MenuDTO> listMenuTrees(@Valid MenuQueryParam param) {
        return this.menuClient.listMenuTrees(param);
    }
}
