package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;

import com.chelvc.cloud.vehicle.client.RankAwardRecordClient;
import com.chelvc.cloud.vehicle.client.dto.RankAwardRecordDTO;
import com.chelvc.cloud.vehicle.client.param.HandRankAwardParam;
import com.chelvc.cloud.vehicle.client.param.QueryRankAwardRecordParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 排行榜派奖记录
 */
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class RankAwardRecordController {
    private final RankAwardRecordClient rankAwardRecordClient;

    /**
     * 查询列表
     *
     * @param param
     * @author igl
     * @date 2024/2/23 17:25
     */
    @GetMapping("/rank-award-record/list")
    public Pagination<RankAwardRecordDTO> list(QueryRankAwardRecordParam param) {
        return this.rankAwardRecordClient.queryPageList(param);
    }

    /**
     * 手动发奖
     *
     * @param param
     * @author igl
     * @date 2024/2/23 17:25
     */
    @PostMapping("/hand-out/prizes")
    public void handOutPrize(@RequestBody @Valid HandRankAwardParam param) {
        this.rankAwardRecordClient.handOutPrize(param);
    }
}
