package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.ReservationClient;
import com.chelvc.cloud.vehicle.client.constant.ReserveStatus;
import com.chelvc.cloud.vehicle.client.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.client.param.ReservationPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.oauth.annotation.Authorize;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 预约管理接口
 *
 * @author liude
 * @Date 2023/1/19
 **/
@Authorize
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class ReservationController {
    private final ReservationClient reservationClient;

    /**
     * 查询预约管理分页
     *
     * @param param 查询参数
     * @return 预约管理分页信息
     */
    @GetMapping("/reservation/paging")
    public Pagination<ReservationDTO> getReservationPaging(@Valid ReservationPagingParam param) {
        return this.reservationClient.getReservationPaging(param);
    }

    /**
     * 更新预约单的状态
     *
     * @param id     预约单ID
     * @param status 预约单的状态
     */
    @PutMapping("/updateReservationsStatus/{id}")
    public void updateReservationsStatus(@PathVariable("id") @Min(value = 1, message = "主键不能小于1") Long id,
                                         @Valid ReserveStatus status) {
        this.reservationClient.updateReservationsStatus(id, status);
    }

    /**
     * 获取预约详情
     *
     * @param id 预约单ID
     */
    @GetMapping("/reservation/{id}")
    public ReservationDTO getDetail(@PathVariable("id") @Min(value = 1, message = "主键不能小于1") Long id) {
        return this.reservationClient.getDetail(id);
    }

}
